@@ -3,7 +3,7 @@ import math
 import re
 import pymongo
 from util_hj3415 import utils
-from setting import load as load_setting
+from .setting import load as load_setting
 from collections import OrderedDict
 import logging
 
@@ -12,7 +12,7 @@ formatter = logging.Formatter('%(levelname)s: [%(name)s] %(message)s')
 ch = logging.StreamHandler()
 ch.setFormatter(formatter)
 logger.addHandler(ch)
-logger.setLevel(logging.INFO)
+logger.setLevel(logging.WARNING)
 
 
 class Base:
